@@ -45,9 +45,11 @@ class SyntaxMUI:
             host="127.0.0.1", 
             port="5050", 
             user_icon="👩🏿‍🦲",
-            bot_icon='<img src="../static/icons/favicon.png" alt="bot icon" width="20"/>',           
-            favicon='<img src="../static/icons/favicon.png" width="10"/>',          
-            site_logo='<img src="../static/icons/logo.png" width="30" alt="SMX Logo"/>',
+            bot_icon="<img src='../static/icons/favicon.png' alt='bot icon' width='20'/>",           
+            favicon="",
+            smxicon="../static/icons/favicon.png",   
+            # <link rel="icon" type="image/png" href="{smx.favicon}">       
+            site_logo="<img src='../static/icons/logo.png' width='30' alt='SMX Logo'/>",
             site_title="SyntaxMatrix", 
             project_name="smxAI", 
             theme_name="light",
@@ -60,6 +62,7 @@ class SyntaxMUI:
         self.user_icon = user_icon
         self.bot_icon = bot_icon
         self.favicon = favicon
+        self.smxicon = smxicon
         self.site_title = site_title
         self.site_logo = site_logo
         self.project_name = project_name
@@ -82,13 +85,13 @@ class SyntaxMUI:
         self.admin_pdf_chunks = {}   # In-memory store for admin PDF chunks
         self.user_file_chunks = {}  # In-memory store of user‑uploaded chunks, scoped per chat session
         routes.setup_routes(self)
-
+        
+        self._admin_profile = {}
         self._chat_profile = {}
         self._coding_profile = {}
         self._classification_profile = {}
         self._summarization_profile = {}
-        self._admin_profile = {}
-    
+            
         self._gpt_models_latest_prev_resp_ids = {}
         self.is_streaming = False
         self.stream_args = {}
@@ -454,7 +457,6 @@ class SyntaxMUI:
     def embed_query(self, q):
         return embed_text(q)
     
-
     def smiv_index(self, sid):
             chunks = self.get_user_chunks(sid) or []
             count = len(chunks)
@@ -480,7 +482,6 @@ class SyntaxMUI:
                 self._user_index_counts[sid] = count
             return self._user_indices[sid]
 
-
     def load_embed_model(self):
         client = load_embed_model()
         os.environ["PROVIDER"] = client["provider"]
@@ -488,11 +489,9 @@ class SyntaxMUI:
         os.environ["OPENAI_API_KEY"] = client["api_key"]
         return client
     
-
     def save_embed_model(self, provider:str, model:str, api_key:str):
         return save_embed_model(provider, model, api_key)
     
-
     def delete_embed_key(self):
         return delete_embed_key()
 
@@ -500,7 +499,6 @@ class SyntaxMUI:
         from syntaxmatrix.settings.model_map import GPT_MODELS_LATEST
         return GPT_MODELS_LATEST
 
-
     def get_text_input_value(self, key, default=""):
         q = session.get(key, default)
         
@@ -510,14 +508,23 @@ class SyntaxMUI:
             return q, None   
         return q, intent
 
+    def enable_stream(self):
+        self.is_streaming = True 
+    
+    def stream(self):
+        return self.is_streaming
+    
+    def get_stream_args(self):
+        return self.stream_args
+
 
     def classify_query_intent(self, query: str) -> str:
         from syntaxmatrix.gpt_models_latest import extract_output_text as _out, set_args 
    
         if not self._classification_profile:
-            classification_profile = _prof.get_profile('classification') or _prof.get_profile('admin')
+            classification_profile = _prof.get_profile('classification') or _prof.get_profile('chat') or _prof.get_profile('admin')
             if not classification_profile:
-                return None
+                return {"Error": "Set a profile for Classification"}
             self._classification_profile = classification_profile
             self._classification_profile['client'] = _prof.get_client(classification_profile)
 
@@ -526,7 +533,8 @@ class SyntaxMUI:
         _model = self._classification_profile['model']
 
         # New instruction format with hybrid option
-        instructions = f"""
+        _intent_profile = "You are an intent classifier. Respond ONLY with the intent name."
+        _instructions = f"""
             Classify the given query into ONE of these intents You must return ONLY the intent name with no comment or any preamble:
             - "none": Casual chat/greetings
             - "user_docs": Requires user-uploaded documents
@@ -545,17 +553,15 @@ class SyntaxMUI:
             Query: "{query}"
             Intent: 
         """
-        intent_profile = "You are an intent classifier. Respond ONLY with the intent name."
-
         openai_sdk_messages = [
-            {"role": "system", "content": intent_profile},
-            {"role": "user", "content": instructions}
+            {"role": "system", "content": _intent_profile},
+            {"role": "user", "content": _instructions}
         ]
 
         def google_classify_query():
             response = _client.models.generate_content(
                 model=_model,
-                contents=f"{intent_profile}\n{instructions}\n\n"
+                contents=f"{_intent_profile}\n{_instructions}\n\n"
             )
             return response.text.strip().lower()
 
@@ -563,8 +569,8 @@ class SyntaxMUI:
                              
             args = set_args(
                 model=_model,
-                instructions=intent_profile,
-                input=instructions,
+                instructions=_intent_profile,
+                input=_instructions,
                 reasoning_effort=reasoning_effort,
                 verbosity=verbosity,
             )
@@ -574,7 +580,21 @@ class SyntaxMUI:
                 return answer if answer else ""
             except Exception as e:
                 return f"Error!"
-            
+        
+        def anthropic_classify_query():       
+            try:
+                response = _client.messages.create(
+                    model=_model,
+                    max_tokens=1024,
+                    system=_intent_profile,
+                    messages=[{"role": "user", "content":_instructions}],
+                    stream=False,
+                )
+                return response.content[0].text.strip()    
+                   
+            except Exception as e:
+                return f"Error: {str(e)}"
+
         def openai_sdk_classify_query():
             try:
                 response = _client.chat.completions.create(
@@ -602,20 +622,20 @@ class SyntaxMUI:
     def generate_contextual_title(self, chat_history):
         
         if not self._summarization_profile:
-            summarization_profile = _prof.get_profile('summarization') or _prof.get_profile('admin') 
+            summarization_profile = _prof.get_profile('summarization') or _prof.get_profile('chat') or _prof.get_profile('admin') 
             if not summarization_profile:
-                return None
+                return {"Error": "Chat profile not set yet."}
             
             self._summarization_profile = summarization_profile
             self._summarization_profile['client'] = _prof.get_client(summarization_profile)
 
         conversation = "\n".join([f"{role}: {msg}" for role, msg in chat_history])
-        title_profile = "You are a title generator. Your task is to create a concise and relevant title for the given conversation."
-        instructions = f"""
-                Generate a contextual title (5 short words max) from the given Conversation History 
-                The title should be concise - with no preamble, relevant, and capture the essence of this Conversation: \n{conversation}.\n\n
-                return only the title.
-            """
+        _title_profile = "You are a title generator that creates concise and relevant titles for the given conversations."
+        _instructions = f"""
+            Generate a contextual title (5 short words max) from the given Conversation History 
+            The title should be concise - with no preamble, relevant, and capture the essence of this Conversation: \n{conversation}.\n\n
+            return only the title.
+        """
         
         _client = self._summarization_profile['client']
         _provider = self._summarization_profile['provider']
@@ -625,7 +645,7 @@ class SyntaxMUI:
             try:
                 response = _client.models.generate_content(
                     model=_model,
-                    contents=f"{title_profile}\n{instructions}"
+                    contents=f"{_title_profile}\n{_instructions}"
                 )
                 title = response.text.strip().lower()
                 return title
@@ -636,8 +656,8 @@ class SyntaxMUI:
             try:                 
                 args = set_args(
                     model=_model,
-                    instructions=title_profile,
-                    input=instructions,
+                    instructions=_title_profile,
+                    input=_instructions,
                     reasoning_effort=reasoning_effort,
                     verbosity=verbosity,
                 )
@@ -647,11 +667,24 @@ class SyntaxMUI:
                 return title if title else "none"
             except Exception as e:
                 return f"Error!"
-
+        
+        def anthropic_generated_title():       
+            try:
+                response = _client.messages.create(
+                    model=_model,
+                    max_tokens=1024,
+                    system=_title_profile,
+                    messages=[{"role": "user", "content":_instructions}],
+                    stream=False,
+                )
+                return response.content[0].text.strip()  
+            except Exception as e:
+                return f"Error!"
+            
         def openai_sdk_generated_title():     
             prompt = [
-                { "role": "system", "content": title_profile }, 
-                { "role": "user", "content": instructions },
+                { "role": "system", "content": _title_profile }, 
+                { "role": "user", "content": _instructions },
             ]
 
             try:
@@ -670,20 +703,13 @@ class SyntaxMUI:
             title = google_generated_title()
         elif _model in self.gpt_models_latest():
             title = gpt_models_latest_generated_title()
+        elif _provider == "anthropic":
+            title = anthropic_generated_title()
         else:
             title = openai_sdk_generated_title()
         return title
     
-    
-    def enable_stream(self):
-        self.is_streaming = True 
-    
-    def stream(self):
-        return self.is_streaming
-    
-    def get_stream_args(self):
-        return self.stream_args
-    
+
     def stream_process_query(self, query, context, conversations, sources):
         self.stream_args['query'] = query
         self.stream_args['context'] = context
@@ -724,22 +750,22 @@ class SyntaxMUI:
         _provider = self._chat_profile['provider']
         _client = self._chat_profile['client']
         _model = self._chat_profile['model']
+
+        _contents = f"""
+            {self.prompt_instructions}\n\n 
+            Question: {query}\n
+            Context: {context}\n\n
+            History: {history}\n\n
+            Use conversation continuity if available.
+        """       
         
         try:
-            if _provider == "google":     # Google, non openai skd series
-                google_prompt = f"""
-                    {self.prompt_profile}\n\n
-                    {self.prompt_instructions}\n\n 
-                    Question: {query}\n
-                    Context: {context}\n\n
-                    History: {history}\n\n
-                    Use conversation continuity if available.
-                """                        
+            if _provider == "google":     # Google, non openai skd series                 
                 contents = [
                     types.Content(
                         role="user",
                         parts=[
-                            types.Part.from_text(text=f"{google_prompt}"),
+                            types.Part.from_text(text=f"{self.prompt_profile}\n\n{_contents}"),
                         ],
                     ),
                 ]
@@ -770,7 +796,24 @@ class SyntaxMUI:
                     final = s.get_final_response()
                     if getattr(final, "id", None):
                         self._gpt_models_latest_prev_resp_ids[sid] = final.id
-
+            
+            elif _provider == "anthropic":
+                with _client.messages.stream(
+                    max_tokens=1024,
+                    messages=[{"role": "user", "content":f"{self.prompt_profile}\n\n {_contents}"},],
+                    model=_model,
+                ) as stream:
+                    for text in stream.text_stream:
+                        yield text  # end="", flush=True
+            
+                    response = _client.messages.create(
+                    model=_model,
+                    max_tokens=1024,
+                    system=self.prompt_profile,
+                    messages=[{"role": "user", "content":_contents}],
+                    stream=False,
+                )
+                    
             else:  # Assumes standard openai_sdk
                 openai_sdk_prompt = [
                     {"role": "system", "content": self.prompt_profile},
@@ -791,19 +834,15 @@ class SyntaxMUI:
     
     def process_query(self, query, context, history, stream=False):
 
-        if stream:
-            return
         if not self._chat_profile:
             chat_profile = _prof.get_profile("chat") or _prof.get_profile("admin")
             if not chat_profile:
-                self.error("Error: check your profiles setup")
-                return None
-            
+                return "Error: check your profiles setup"
+                 
             self._chat_profile = chat_profile
             self._chat_profile['client'] = _prof.get_client(chat_profile) 
         
-        google_prompt = f"""
-                    {self.prompt_profile}\n\n
+        _contents = f"""
                     {self.prompt_instructions}\n\n 
                     Question: {query}\n
                     Context: {context}\n\n
@@ -813,14 +852,12 @@ class SyntaxMUI:
         
         openai_sdk_prompt = [
                 {"role": "system", "content": self.prompt_profile},
-                {
-                    "role": "user", 
-                    "content": f"""{self.prompt_instructions}\n\n
-                                    Generate response to this query: {query}\n
-                                    based on this context:\n{context}\n
-                                    and history:\n{history}\n\n
-                                    Use conversation continuity if available.)
-                                """
+                {"role": "user", "content": f"""{self.prompt_instructions}\n\n
+                                                Generate response to this query: {query}\n
+                                                based on this context:\n{context}\n
+                                                and history:\n{history}\n\n
+                                                Use conversation continuity if available.)
+                                            """
                 },
             ]
 
@@ -832,7 +869,7 @@ class SyntaxMUI:
             try:
                 response = _client.models.generate_content(
                     model=_model,
-                    contents=google_prompt
+                    contents=f"{self.prompt_profile}\n\n{_contents}"
                 )
                 answer = response.text
                 
@@ -877,7 +914,21 @@ class SyntaxMUI:
 
             except Exception as e:
                 return f"Error: {type(e).__name__}: {e}"
-        
+                     
+        def anthropic_process_query():      
+            try:
+                response = _client.messages.create(
+                    model=_model,
+                    max_tokens=1024,
+                    system=self.prompt_profile,
+                    messages=[{"role": "user", "content":_contents}],
+                    stream=False,
+                )
+                return response.content[0].text.strip()    
+                   
+            except Exception as e:
+                return f"Error: {str(e)}"
+
         def openai_sdk_process_query():
         
             try:
@@ -887,42 +938,34 @@ class SyntaxMUI:
                 stream=False,
                 )
 
-                if stream:
-                    # -------- token streaming --------
-                    parts = []
-                    for chunk in response:
-                        token = getattr(chunk.choices[0].delta, "content", "")
-                        if not token:
-                            continue
-                        parts.append(token)
-                        self.stream_write(token)    
-
-                    self.stream_write("[END]")   # close the SSE bubble  
-                    answer = "".join(parts)  
-
-                    # answer = strip_html(answer)        
-                    return answer      
-                else:
-                    # -------- one-shot buffered --------
-                    answer = response.choices[0].message.content .strip() 
-                    return answer
+                # -------- one-shot buffered --------
+                answer = response.choices[0].message.content .strip() 
+                return answer
             except Exception as e:
                 return f"Error: {str(e)}"
-
+  
         if _provider == "google":
             return google_process_query()
-        elif _provider == "openai" and _model in self.gpt_models_latest():
+        if _provider == "openai" and _model in self.gpt_models_latest():
             return gpt_models_latest_process_query(self._gpt_models_latest_prev_resp_ids.get(self.get_session_id()))
-        else:
-            return openai_sdk_process_query()
+        if _provider == "anthropic":
+            return anthropic_process_query()
+        return openai_sdk_process_query()
 
 
     def ai_generate_code(self, question, df):
     
-        if not self._coding_profile:
-            coding_profile = _prof.get_profile('coding')  or  _prof.get_profile('admin')
+        if not self._coding_profile:            
+            coding_profile = _prof.get_profile("coding") or _prof.get_profile("admin")
             if not coding_profile:
-                return None
+                # tell the user exactly what to configure
+                return (
+                    '<div class="smx-alert smx-alert-warn">'
+                        'No LLM profile configured for <code>coding</code> (or <code>admin</code>). '
+                        'Please,  contact your Administrator.'
+                    '</div>'
+                )
+
             self._coding_profile = coding_profile
             self._coding_profile['client'] = _prof.get_client(coding_profile)
 
@@ -931,7 +974,54 @@ class SyntaxMUI:
         _model = self._coding_profile['model']
 
         context = f"Columns: {list(df.columns)}\n\nDtypes: {df.dtypes.astype(str).to_dict()}\n\n"
-        ai_profile = f"""You are an expert Python coder, engineer, data analyst. You study thoroughly a given dataframe (`df`), a given question, and a given Context to provide accurate and efficient code solutions: visualisations, tables, and commentaries in plain texts, as required."""
+        
+        Linear_regression = """
+            <Instruction for Generating Multiple Linear Regression Analysis Code>
+                You are a data science code generation assistant. Your task is to produce a complete, executable Python script that performs a multiple linear regression analysis based on a user's specific request, using a provided dataset (`df`).
+        
+            <Steps to Generate the Code>
+                <dataset loading>:
+                Assume the dataset is accessible (e.g., via an uploaded file or a provided path).
+                Use pandas (pd) to load the dataset into a DataFrame named df. The specific loading command (pd.read_csv, etc.) should match the dataset's format as implied by the user (e.g., if the user mentions diabetes_dataset.csv, use pd.read_csv('diabetes_dataset.csv')).
+                Print the first few rows (df.head()) and descriptive statistics (df.describe()) of the loaded DataFrame to verify successful loading.
+
+                <Variable Identification>:
+                    <carefully analyze the user's query to identify>:
+                    The target variable (dependent variable) to be predicted (e.g., "predict the level of the liver enzyme GGT").
+                    The specific predictor variables (independent variables) to be used in the model (e.g., "BMI, Waist_Circumference, Alcohol_Consumption, and HbA1c").
+                    Examine the column names of the loaded DataFrame (df.columns) to find the exact column names corresponding to the variables identified in the query. Ensure the column names used in the code exactly match those in the dataset.
+
+                <Data Preparation>:
+                    Select the identified predictor variables and create a feature matrix X.
+                    Select the identified target variable and create a target vector y.
+                    Handle any potential missing values if necessary (e.g., using dropna() or imputation, though for simplicity, dropping rows with missing values in relevant columns is often acceptable for initial analysis).
+                
+                <Model Creation and Training>:
+                    Import necessary modules from sklearn (train_test_split, LinearRegression, mean_squared_error, r2_score).
+                    Split the data into training and testing sets using train_test_split (e.g., 80% train, 20% test).
+                    Instantiate a LinearRegression model.
+                    Fit the model to the training data (model.fit(X_train, y_train)).
+                    Model Evaluation:
+                    Use the trained model to make predictions on the test set (y_pred = model.predict(X_test)).
+                    Calculate performance metrics like R-squared (r2_score) and Mean Squared Error (mean_squared_error) to evaluate how well the model fits the data on the test set.
+                    
+                <Result Interpretation>:
+                    Extract the model's coefficients (model.coef_) and intercept (model.intercept_).
+                    Print the intercept and a list of feature names paired with their corresponding coefficients.
+                    Calculate the absolute values of the coefficients to assess the relative importance of each predictor variable.
+                    Provide a clear interpretation:
+                    Explain what each coefficient means in the context of the problem (e.g., "A 1 unit increase in [Feature Name], holding other variables constant, is associated with a [Coefficient Value] unit change in [Target Variable Name]").
+                    Rank the predictor variables by the absolute value of their coefficients to indicate their relative contribution to the prediction.
+                    
+                <Output Formatting>:
+                    Structure the printed output clearly using section headers (e.g., "=== Multiple Linear Regression Results ===", "=== Interpretation ===").
+                    Ensure the final code is self-contained, uses appropriate variable names, and includes necessary import statements.
+                    Add a comment reminding the user to ensure column names match their actual dataset if they adapt the code.
+        """
+        
+        ai_profile = f"""
+        You are a data science code generation assistant. Your task is to produce a complete, executable Python script that performs a multiple linear regression analysis based on a user's specific request, using a provided dataset (`df`).
+        """
 
         instructions = f"""
             Write clean, working Python code that answers the question below. 
@@ -964,7 +1054,19 @@ class SyntaxMUI:
                 return code
             except Exception as e:
                 return f"Error!"
-        
+
+        def anthropic_generate_code():        
+            try:
+                response = _client.messages.create(
+                    model=_model,
+                    max_tokens=1024,
+                    system=ai_profile,
+                    messages=[{"role": "user", "content":instructions}],
+                    stream=False,
+                )
+                return response.content[0].text.strip()    
+            except Exception as e:
+                return f"Error!"
 
         def openai_sdk_generate_code():
             try:
@@ -979,12 +1081,14 @@ class SyntaxMUI:
                 )
                 return response.choices[0].message.content
             except Exception as e:
-                return f"Error!"
+                return "Error!"
 
         if _provider == 'google':
             code = google_generate_code()
-        elif _model in self.gpt_models_latest():
+        elif _provider == "openai" and _model in self.gpt_models_latest():
             code = gpt_models_latest_generate_code()
+        elif _provider == "anthropic":
+            code = anthropic_generate_code()
         else:
             code = openai_sdk_generate_code()
         
