@@ -29,6 +29,7 @@ PROVIDERS_MODELS = {
         "grok-3-mini-fast",
         "grok-3-mini",
         "grok-3",
+        "grok-4",
     ],
     #4
     "deepseek": [                    
@@ -45,6 +46,13 @@ PROVIDERS_MODELS = {
         "qwen3-coder-plus",
         "qwen-max",
     ],
+    #7
+    "anthropic": [
+        "claude-opus-4-1",
+        "claude-sonnet-4-0",
+        "claude-3-5-haiku-latest",
+        "claude-3-haiku-20240307",
+    ]
 }
 
 
@@ -254,6 +262,19 @@ MODEL_DESCRIPTIONS = {
     > Large-context analysis (32K token window) for documents or data
 
     """,
+
+    "claude-opus-4-1":""" $15 / MTok	$18.75 / MTok	$30 / MTok	$1.50 / MTok	$75 / MTok
+    """,
+
+    "claude-sonnet-4-0":""" $3 / MTok	$3.75 / MTok	$6 / MTok	$0.30 / MTok	$15 / MTok
+    """,
+
+    "claude-haiku-3-5-latest":""" $0.80 / MTok	$1 / MTok	$1.6 / MTok	$0.08 / MTok	$4 / MTok   
+    """,
+
+    "claude-3-haiku-20240307":""" $0.25 / MTok	$0.30 / MTok	$0.50 / MTok	$0.03 / MTok	$1.25 / MTok
+    """,
+
 }
 
 
