@@ -639,29 +639,59 @@ def fix_numeric_aggs(code: str) -> str:
 
 def ensure_accuracy_block(code: str) -> str:
     """
-    If the code fits an estimator but never prints accuracy,
-    inject an evaluation block that re-uses *whatever variable name*
-    appears immediately before `.fit(`.
+    Inject a sensible evaluation block right after the last `<est>.fit(...)`
+    Classification → accuracy + weighted F1
+    Regression    → R², RMSE, MAE
+    Heuristic: infer task from estimator names present in the code.
     """
-    # Already prints accuracy? – bail out early
-    if re.search(r"accuracy_score\s*\(", code):
+    import re, textwrap
+
+    # If any proper metric already exists, do nothing
+    if re.search(r"\b(accuracy_score|f1_score|r2_score|mean_squared_error|mean_absolute_error)\b", code):
         return code
 
-    # Find the last `<var>.fit(` call
+    # Find the last "<var>.fit(" occurrence to reuse the estimator variable name
     m = list(re.finditer(r"(\w+)\.fit\s*\(", code))
     if not m:
-        return code                    # no model at all
+        return code  # no estimator
 
-    var = m[-1].group(1)               # estimator variable name
+    var = m[-1].group(1)
+    # indent with same leading whitespace used on that line
     indent = re.match(r"\s*", code[m[-1].start():]).group(0)
 
-    eval_block = textwrap.dedent(f"""
-        {indent}# ── automatic accuracy evaluation ─────────
-        {indent}from sklearn.metrics import accuracy_score
-        {indent}y_pred = {var}.predict(X_test)
-        {indent}acc = accuracy_score(y_test, y_pred)
-        {indent}print(f"Model accuracy on hold-out set: {{acc:.2%}}")
-    """)
+    # Detect regression by estimator names / hints in code
+    is_regression = bool(
+        re.search(
+            r"\b(LinearRegression|Ridge|Lasso|ElasticNet|ElasticNetCV|HuberRegressor|TheilSenRegressor|RANSACRegressor|"
+            r"RandomForestRegressor|GradientBoostingRegressor|DecisionTreeRegressor|KNeighborsRegressor|SVR|"
+            r"XGBRegressor|LGBMRegressor|CatBoostRegressor)\b", code
+        )
+        or re.search(r"\bOLS\s*\(", code)
+        or re.search(r"\bRegressor\b", code)
+    )
+
+    if is_regression:
+        # inject numpy import if needed for RMSE
+        if "import numpy as np" not in code and "np." not in code:
+            code = "import numpy as np\n" + code
+        eval_block = textwrap.dedent(f"""
+            {indent}# ── automatic regression evaluation ─────────
+            {indent}from sklearn.metrics import r2_score, mean_squared_error, mean_absolute_error
+            {indent}y_pred = {var}.predict(X_test)
+            {indent}r2 = r2_score(y_test, y_pred)
+            {indent}rmse = float(np.sqrt(mean_squared_error(y_test, y_pred)))
+            {indent}mae = float(mean_absolute_error(y_test, y_pred))
+            {indent}print(f"R²: {{r2:.4f}} | RMSE: {{rmse:.4f}} | MAE: {{mae:.4f}}")
+        """)
+    else:
+        eval_block = textwrap.dedent(f"""
+            {indent}# ── automatic classification evaluation ─────────
+            {indent}from sklearn.metrics import accuracy_score, f1_score
+            {indent}y_pred = {var}.predict(X_test)
+            {indent}acc = accuracy_score(y_test, y_pred)
+            {indent}f1  = f1_score(y_test, y_pred, average='weighted')
+            {indent}print(f"Accuracy: {{acc:.2%}} | F1 (weighted): {{f1:.3f}}")
+        """)
 
     insert_at = code.find("\n", m[-1].end()) + 1
     return code[:insert_at] + eval_block + code[insert_at:]
@@ -755,50 +785,168 @@ def ensure_preproc_in_pipeline(code: str) -> str:
 
 def fix_plain_prints(code: str) -> str:
     """
-    Rewrite  print(<var>)  → show(<var>)  when <var> looks like
-    a pandas / numpy / sklearn object (heuristic: not a string literal).
+    Rewrite bare `print(var)` where var looks like a dataframe/series/ndarray/etc
+    to go through SyntaxMatrix's smart display (so it renders in the dashboard).
+    Keeps string prints alone.
     """
     import re
-    return re.sub(
-        r"print\((\w+)\)",
+    # Skip obvious string-literal prints
+    new = re.sub(
+        r"(?m)^\s*print\(\s*([A-Za-z_]\w*)\s*\)\s*$",
         r"from syntaxmatrix.display import show\nshow(\1)",
         code,
     )
+    return new
 
+def fix_print_html(code: str) -> str:
+    """
+    Ensure that HTML / DataFrame HTML are *displayed* (and captured by the kernel),
+    not printed as `<IPython.core.display.HTML object>` to the server console.
+    - Rewrites: print(HTML(...))  → display(HTML(...))
+                print(display(...)) → display(...)
+                print(df.to_html(...)) → display(HTML(df.to_html(...)))
+    Also prepends `from IPython.display import display, HTML` if required.
+    """
+    import re
+
+    new = code
+
+    # 1) print(HTML(...)) -> display(HTML(...))
+    new = re.sub(r"(?m)^\s*print\s*\(\s*HTML\s*\(", "display(HTML(", new)
+
+    # 2) print(display(...)) -> display(...)
+    new = re.sub(r"(?m)^\s*print\s*\(\s*display\s*\(", "display(", new)
+
+    # 3) print(<expr>.to_html(...)) -> display(HTML(<expr>.to_html(...)))
+    new = re.sub(
+        r"(?m)^\s*print\s*\(\s*([A-Za-z_]\w*(?:\.[A-Za-z_]\w*)*)\s*\.to_html\s*\(",
+        r"display(HTML(\1.to_html(", new
+    )
+
+    # If code references HTML() or display() make sure the import exists
+    if ("HTML(" in new or re.search(r"\bdisplay\s*\(", new)) and \
+        "from IPython.display import display, HTML" not in new:
+        new = "from IPython.display import display, HTML\n" + new
+
+    return new
+
+def ensure_ipy_display(code: str) -> str:
+    """
+    Guarantee that the cell has proper IPython display imports so that
+    display(HTML(...)) produces 'display_data' events the kernel captures.
+    """
+    if "display(" in code and "from IPython.display import display, HTML" not in code:
+        return "from IPython.display import display, HTML\n" + code
+    return code
 # --------------------------------------------------------------------------
 #  ✂
 # --------------------------------------------------------------------------
-def drop_bad_classification_metrics(code: str, y) -> str:
+def drop_bad_classification_metrics(code: str, y_or_df) -> str:
     """
-    If the prediction target is continuous (i.e. a regression task) and the
-    generated code mistakenly calls classification metrics such as
-    `accuracy_score`, `classification_report`, or `confusion_matrix`,
-    comment those lines out so the cell can still run.
-
-    Works whether `y` is:
-      • a pandas Series  ->  y.dtype.kind is available
-      • a pandas DataFrame (multi-column)  ->  we infer by looking at *all*
+    Remove classification metrics (accuracy_score, classification_report, confusion_matrix)
+    if the generated cell is *regression*. We infer this from:
+      1) The estimator names in the code (LinearRegression, OLS, Regressor*, etc.), OR
+      2) The target dtype if we can parse y = df['...'] and have the DataFrame.
+    Safe across datasets and queries.
     """
-    # ── decide whether y looks continuous ────────────────────────────────
-    try:
-        kind = y.dtype.kind                          # Series path
-    except AttributeError:
-        # DataFrame path: regression if *every* column’s dtype is numeric/datetime
-        numeric_kinds = set("fiuM")                  # float, int, unsigned, datetime
-        col_kinds = {dt.kind for dt in getattr(y, "dtypes", [])}
-        kind = "f" if col_kinds and col_kinds.issubset(numeric_kinds) else "O"
+    import re
+    import pandas as pd
 
-    # ── if regression, strip classification lines ───────────────────────
-    if kind in "fM":                                 # float or datetime
-        patterns = [
-            r"\n.*accuracy_score[^\n]*",
-            r"\n.*classification_report[^\n]*",
-            r"\n.*confusion_matrix[^\n]*",
-        ]
-        for pat in patterns:
+    # 1) Heuristic by estimator names in the *code* (fast path)
+    regression_by_model = bool(re.search(
+        r"\b(LinearRegression|Ridge|Lasso|ElasticNet|ElasticNetCV|HuberRegressor|TheilSenRegressor|RANSACRegressor|"
+        r"RandomForestRegressor|GradientBoostingRegressor|DecisionTreeRegressor|KNeighborsRegressor|SVR|"
+        r"XGBRegressor|LGBMRegressor|CatBoostRegressor)\b", code
+    ) or re.search(r"\bOLS\s*\(", code))
+
+    is_regression = regression_by_model
+
+    # 2) If not obvious from the model, try to infer from y dtype (if we can)
+    if not is_regression:
+        try:
+            # Try to parse: y = df['target']
+            m = re.search(r"y\s*=\s*df\[['\"]([^'\"]+)['\"]\]", code)
+            if m and hasattr(y_or_df, "columns") and m.group(1) in getattr(y_or_df, "columns", []):
+                y = y_or_df[m.group(1)]
+                if pd.api.types.is_numeric_dtype(y) and y.nunique(dropna=True) > 10:
+                    is_regression = True
+            else:
+                # If a Series was passed
+                y = y_or_df
+                if hasattr(y, "dtype") and pd.api.types.is_numeric_dtype(y) and y.nunique(dropna=True) > 10:
+                    is_regression = True
+        except Exception:
+            pass
+
+    if is_regression:
+        # Strip classification-only lines
+        for pat in (r"\n.*accuracy_score[^\n]*", r"\n.*classification_report[^\n]*", r"\n.*confusion_matrix[^\n]*"):
             code = re.sub(pat, "", code, flags=re.I)
 
     return code
 
-# from syntaxmatrix.core import SyntaxMUI
-# ai_generate_code = SyntaxMUI.ai_generate_code
\ No newline at end of file
+def force_capture_display(code: str) -> str:
+    """
+    Ensure our executor captures HTML output:
+    - Remove any import that would override our 'display' hook.
+    - Keep/allow importing HTML only.
+    - Handle alias cases like 'display as d'.
+    """
+    import re
+    new = code
+
+    # 'from IPython.display import display, HTML' -> keep HTML only
+    new = re.sub(
+        r"(?m)^\s*from\s+IPython\.display\s+import\s+display\s*,\s*HTML\s*(?:as\s+([A-Za-z_]\w*))?\s*$",
+        r"from IPython.display import HTML\1", new
+    )
+
+    # 'from IPython.display import display as d' -> 'd = display'
+    new = re.sub(
+        r"(?m)^\s*from\s+IPython\.display\s+import\s+display\s+as\s+([A-Za-z_]\w+)\s*$",
+        r"\1 = display", new
+    )
+
+    # 'from IPython.display import display' -> remove (use our injected display)
+    new = re.sub(
+        r"(?m)^\s*from\s+IPython\.display\s+import\s+display\s*$",
+        r"# display import removed (SMX capture active)", new
+    )
+
+    # If someone does 'import IPython.display as disp' and calls disp.display(...), rewrite to display(...)
+    new = re.sub(
+        r"(?m)\bIPython\.display\.display\s*\(",
+        "display(", new
+    )
+    new = re.sub(
+        r"(?m)\b([A-Za-z_]\w*)\.display\s*\("  # handles 'disp.display(' after 'import IPython.display as disp'
+        r"(?=.*import\s+IPython\.display\s+as\s+\1)",
+        "display(", new
+    )
+    return new
+
+def strip_matplotlib_show(code: str) -> str:
+    """Remove blocking plt.show() calls (we export base64 instead)."""
+    import re
+    return re.sub(r"(?m)^\s*plt\.show\(\)\s*$", "", code)
+
+def inject_display_shim(code: str) -> str:
+    """
+    Provide display()/HTML() if missing, forwarding to our executor hook.
+    Harmless if the names already exist.
+    """
+    shim = (
+        "try:\n"
+        "    display\n"
+        "except NameError:\n"
+        "    def display(obj=None, **kwargs):\n"
+        "        __builtins__.get('_smx_display', print)(obj)\n"
+        "try:\n"
+        "    HTML\n"
+        "except NameError:\n"
+        "    class HTML:\n"
+        "        def __init__(self, data): self.data = str(data)\n"
+        "        def _repr_html_(self): return self.data\n"
+        "\n"
+    )
+    return shim + code
